@@ -20,5 +20,12 @@ public class DebugProtocol {
   /**
    * Version of Debug Protocol
    */
-  public static final String SCHEMA_VERSION = "1.58.0";
+  public static final String SCHEMA_VERSION = "1.60.0";
+
+  /**
+   * Refer to the Debug Adapter Protocol's
+   * <a href="https://microsoft.github.io/debug-adapter-protocol/overview">Overview</a> on the
+   * specification's website.
+   */
+  public static final String Overview = "Overview";
 }
